--
-- replaceJoint
--
-- @author:    	Xentro (www.fs-uk.com)(Marcus@Xentro.se)
-- @version:    v1.0
-- @date:       2013-07-12
-- 
--[[
<replaceJoint index="" animation="" trigger="" inputbinding="" />
]]--

replaceJoint = {};

function replaceJoint.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end;

function replaceJoint:load(xmlFile)
	self.replaceTriggerCallback = replaceJoint.replaceTriggerCallback;
	
	local node = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.replaceJoint#index"));
	local triggerNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.replaceJoint#trigger"));
	if node ~= nil and triggerNode ~= nil and self.attacherJoint ~= nil then
		self.replaceJoints = {};
		self.replaceJoints[1] = self.attacherJoint.node;
		self.replaceJoints[2] = node;
		self.replaceJoints["trigger"] = triggerNode;
		self.replaceJoints["inRange"] = false;
		self.replaceJoints["update"] = false;
		
		local input = getXMLString(xmlFile, "vehicle.replaceJoint#inputbinding");
		if input ~= nil and input ~= "" and InputBinding[input] ~= nil then
			self.replaceJoints["inputbinding"] = InputBinding[input];
		else
			self.replaceJoints["inputbinding"] = InputBinding.IMPLEMENT_EXTRA;
		end;
		
		local animation = getXMLString(xmlFile, "vehicle.replaceJoint#animation");
		if animation ~= nil and self.animations[animation] ~= nil then
			self.replaceJoints["animation"] = animation;
		else
			self.replaceJoints["saveId"] = true;
		end;
		
		addTrigger(self.replaceJoints["trigger"], "replaceTriggerCallback", self);
	end;
end;

function replaceJoint:delete()
	if self.replaceJoints ~= nil then
		removeTrigger(self.replaceJoints["trigger"]);
	end;
end;

function replaceJoint:mouseEvent(posX, posY, isDown, isUp, button)
end;

function replaceJoint:keyEvent(unicode, sym, modifier, isDown)
end;

function replaceJoint:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if not resetVehicles then
		local replaceJointTime = getXMLFloat(xmlFile, key .. "#replaceJointTime");
		
		if replaceJointTime ~= nil then
			local speed = 1;
			if replaceJointTime < 0.5 then
				speed = -1;
			end
			
			if replaceJointTime ~= 0 then
				self.attacherJoint.node = self.replaceJoints[2];
			end;
			
			self:playAnimation(self.replaceJoints["animation"], speed);
			self:setAnimationTime(self.replaceJoints["animation"], replaceJointTime);
			self:updateCylinderedInitial();
		else
			local id = getXMLInt(xmlFile, key .. "#replaceJointId");
			
			if id ~= nil then
				self.attacherJoint.node = self.replaceJoints[id];
			end;
		end;
	end; 

    return BaseMission.VEHICLE_LOAD_OK;
end;

function replaceJoint:getSaveAttributesAndNodes(nodeIdent)	
	local attributes = "";
	
	if self.replaceJoints ~= nil then
		if self.replaceJoints["animation"] ~= nil then
			attributes = 'replaceJointTime="' .. self:getAnimationTime(self.replaceJoints["animation"]) .. '"';
		else
			if self.replaceJoints["saveId"] then
				local id = 1;
				if self.attacherJoint.node == self.replaceJoints[2] then
					id = 2;
				end;
				
				attributes = 'replaceJointId="' .. id .. '"';
			end;
		end;
	end;
	
    return attributes, nil;
end;

function replaceJoint:update(dt)
	if self.replaceJoints ~= nil and self.attacherVehicle == nil then
		if g_gui.currentGui == nil and not g_currentMission.isPlayerFrozen then
			if self.replaceJoints["inRange"] and g_currentMission.controlPlayer and self.isClient then
				if self.replaceJoints["animation"] ~= nil then
					if InputBinding.hasEvent(self.replaceJoints["inputbinding"]) then
						if self:getAnimationTime(self.replaceJoints["animation"]) <= 0.5 then
							self:playAnimation(self.replaceJoints["animation"], 1);
						else
							self:playAnimation(self.replaceJoints["animation"], -1);
						end;
					end;
					
					if g_i18n:hasText("REPLACE_JOINT") then
						g_currentMission:addHelpButtonText(g_i18n:getText("REPLACE_JOINT"), self.replaceJoints["inputbinding"]);
					end;
				end;
			end;
		end;
	end;
end;

function replaceJoint:updateTick(dt)
	if self.replaceJoints ~= nil and self.attacherVehicle == nil then
		local animationTime = 0;
		local node;
		
		if self.replaceJoints["animation"] ~= nil then
			animationTime = self:getAnimationTime(self.replaceJoints["animation"]);
		else
			if self.attacherJoint.node ~= self.replaceJoints[1] then
				animationTime = 1;
			end;
			
			if self.replaceJoints["update"] then
				if self.attacherJoint.node == self.replaceJoints[1] then
					animationTime = 1;
				else
					animationTime = 0;
				end;
				
				self.replaceJoints["update"] = false;
			end;
		end;
		
		if animationTime == 0 then
			node = self.replaceJoints[1];
		else
			node = self.replaceJoints[2];
		end;
		
		if node ~= nil then
			if self.attacherJoint.node ~= node then
				self.attacherJoint.node = node;
			end;
		end;
	end;
end;

function replaceJoint:draw()
end;

function replaceJoint:replaceTriggerCallback(triggerId, otherId, onEnter, onLeave, onStay, otherShapeId)
	if onEnter or onLeave then
		if g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
			if onEnter then
				self.replaceJoints["inRange"] = true;
			else
				self.replaceJoints["inRange"] = false;
			end;
		end;
	end;
end;